NAME

DesktopWorkspaceRole::Spec::Basic - Required methods for all DesktopWorkspace::* modules

VERSION

This document describes version 1.0.0 of DesktopWorkspaceRole::Spec::Basic (from Perl distribution DesktopWorkspace), released on 2026-03-29.

DESCRIPTION

category                     method name                   note
--------                     -----------                   -------
instantiating                new(%args)

properties                   items([ $val ])
                             kde_activity([ $val ])
                             new_browser_window([ $val ])

ROLES MIXED IN

None.

REQUIRED METHODS

new

Usage:

my $dw = DesktopWorkspace::Foo->new([ %args ]);

Constructor. Must accept a pair of argument names and values.

items

Get or set items.

kde_activity

Get or set the kde_activity property.

new_browser_window

Get or set the new_browser_window property.

PROVIDED METHODS

None.

HOMEPAGE

Please visit the project's homepage at https://metacpan.org/release/DesktopWorkspace.

SOURCE

Source repository is at https://github.com/perlancar/perl-DesktopWorkspace.

SEE ALSO

AUTHOR

perlancar <perlancar@cpan.org>

CONTRIBUTING

To contribute, you can send patches by email/via RT, or send pull requests on GitHub.

Most of the time, you don't need to build the distribution yourself. You can simply modify the code, then test via:

% prove -l

If you want to build the distribution (e.g. to try to install it locally on your system), you can install Dist::Zilla, Dist::Zilla::PluginBundle::Author::PERLANCAR, Pod::Weaver::PluginBundle::Author::PERLANCAR, and sometimes one or two other Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond that are considered a bug and can be reported to me.

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

BUGS

Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=DesktopWorkspace

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.